@@ -11,7 +11,7 @@ from graphinder.entities.io import Results
 from graphinder.entities.tasks import TasksList
 from graphinder.io.printers import display_results
 from graphinder.io.readers import read_domains
-from graphinder.io.writers import write_results
+from graphinder.io.writers import write_results, write_results_inplace
 from graphinder.pool.domain import Domain, Url
 from graphinder.pool.tasks import consume_tasks, init_domain_tasks
 from graphinder.utils.filters import filter_urls
@@ -58,8 +58,9 @@ def main_routine(args: argparse.Namespace) -> Results:
     args.max_workers = min(args.max_workers, len(domains))
 
     output_file = args.output_file
-    del args.input_file
+    input_file = args.input_file
     del args.output_file
+    del args.input_file
 
     exported_results: Results = {}
 
@@ -77,6 +78,9 @@ def main_routine(args: argparse.Namespace) -> Results:
         if output_file is not None:
             write_results(output_file, results.copy())
 
+        if args.inplace:
+            write_results_inplace(input_file, results.copy())
+
         if args.webhook_url is not None:
             send_webhook(args.webhook_url, results)
 
